@@ -14,7 +14,7 @@ def test_readinggrid():
     doc = Document(**doc)
     nb_sents = len(doc.sentences)
     nb_annots = len(doc.annotations)
-    parameters = ReadingGridParameters(separator="\n\u22ee\n")
+    parameters = ReadingGridParameters(separator="\u22ee")
     formatter = ReadingGridProcessor()
     docs = formatter.process([doc], parameters)
     assert len(docs[0].sentences) < nb_sents
